@@ -417,8 +417,9 @@ QStringList AkElement::listPluginPaths()
     for (int i = akElementGlobalStuff->m_pluginsSearchPaths.length() - 1; i >= 0; i--) {
         QStringList paths = AkElement::listPluginPaths(akElementGlobalStuff->m_pluginsSearchPaths[i]);
 
-        if (!paths.isEmpty())
-            searchPaths << paths;
+        foreach (QString path, paths)
+            if (!searchPaths.contains(path))
+                searchPaths << path;
     }
 
     akElementGlobalStuff->m_pluginsCache = searchPaths;
@@ -526,9 +527,11 @@ bool AkElement::setState(AkElement::ElementState state)
             emit this->stateChange(ElementStatePaused, state);
 
             break;
-        default:
+        case ElementStateNull:
             break;
         }
+
+        break;
     }
     case ElementStatePaused: {
         switch (state) {
@@ -538,9 +541,11 @@ bool AkElement::setState(AkElement::ElementState state)
             emit this->stateChange(preState, state);
 
             break;
-        default:
+        case ElementStatePaused:
             break;
         }
+
+        break;
     }
     case ElementStatePlaying: {
         switch (state) {
@@ -557,13 +562,13 @@ bool AkElement::setState(AkElement::ElementState state)
             emit this->stateChange(preState, state);
 
             break;
-        default:
+        case ElementStatePlaying:
             break;
         }
-    }
-    default:
+
         break;
     }
+    }
 
     return true;
 }
