@@ -35,6 +35,11 @@
 class CameraOut: public QObject
 {
     Q_OBJECT
+    Q_PROPERTY(QString driverPath
+               READ driverPath
+               WRITE setDriverPath
+               RESET resetDriverPath
+               NOTIFY driverPathChanged)
     Q_PROPERTY(QStringList webcams
                READ webcams
                NOTIFY webcamsChanged)
@@ -47,27 +52,50 @@ class CameraOut: public QObject
                READ streamIndex)
     Q_PROPERTY(AkCaps caps
                READ caps)
+    Q_PROPERTY(int maxCameras
+               READ maxCameras)
+    Q_PROPERTY(bool needRoot
+               READ needRoot)
+    Q_PROPERTY(int passwordTimeout
+               READ passwordTimeout
+               WRITE setPasswordTimeout
+               RESET resetPasswordTimeout
+               NOTIFY passwordTimeoutChanged)
 
     public:
         explicit CameraOut();
         ~CameraOut();
 
+        Q_INVOKABLE QString driverPath() const;
         Q_INVOKABLE QStringList webcams() const;
         Q_INVOKABLE QString device() const;
         Q_INVOKABLE int streamIndex() const;
         Q_INVOKABLE AkCaps caps() const;
         Q_INVOKABLE QString description(const QString &webcam) const;
         Q_INVOKABLE void writeFrame(const AkPacket &frame);
+        Q_INVOKABLE int maxCameras() const;
+        Q_INVOKABLE bool needRoot() const;
+        Q_INVOKABLE int passwordTimeout() const;
+        Q_INVOKABLE QString createWebcam(const QString &description="",
+                                         const QString &password="") const;
+        Q_INVOKABLE bool changeDescription(const QString &webcam,
+                                           const QString &description="",
+                                           const QString &password="") const;
+        Q_INVOKABLE bool removeWebcam(const QString &webcam,
+                                      const QString &password="") const;
+        Q_INVOKABLE bool removeAllWebcams(const QString &password="") const;
 
     private:
+        QString m_driverPath;
         QStringList m_webcams;
         QString m_device;
         int m_streamIndex;
         AkCaps m_caps;
+        int m_passwordTimeout;
         QFileSystemWatcher *m_fsWatcher;
         int m_fd;
 
-        inline int xioctl(int fd, int request, void *arg) const
+        inline int xioctl(int fd, ulong request, void *arg) const
         {
             int r = -1;
 
@@ -81,16 +109,24 @@ class CameraOut: public QObject
             return r;
         }
 
+        bool sudo(const QString &command, const QString &password) const;
+
     signals:
+        void driverPathChanged(const QString &driverPath);
         void webcamsChanged(const QStringList &webcams) const;
         void deviceChanged(const QString &device);
+        void passwordTimeoutChanged(int passwordTimeout);
         void error(const QString &message);
 
     public slots:
         bool init(int streamIndex, const AkCaps &caps);
         void uninit();
+        void setDriverPath(const QString &driverPath);
         void setDevice(const QString &device);
+        void setPasswordTimeout(int passwordTimeout);
+        void resetDriverPath();
         void resetDevice();
+        void resetPasswordTimeout();
 
     private slots:
         void onDirectoryChanged(const QString &path);
